# This file is generated by objective.metadata
#
# Last update: Sat Jun 27 18:38:17 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$$"""
enums = """$$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSMailDelivery",
        b"deliverMessage:headers:format:protocol:",
        {"retval": {"type": "Z"}},
    )
    r(b"NSMailDelivery", b"deliverMessage:subject:to:", {"retval": {"type": "Z"}})
    r(b"NSMailDelivery", b"hasDeliveryClassBeenConfigured", {"retval": {"type": "Z"}})
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



"""
Wrappers for the "Message" framework on macOS. This framework contains a
number of utilities for sending e-mail.

These wrappers don't include documentation, please check Apple's documention
for information on how to use this framework and PyObjC's documentation
for general tips and tricks regarding the translation between Python
and (Objective-)C frameworks
"""
from pyobjc_setup import setup

VERSION = '7.2'

setup(
    name="pyobjc-framework-Message",
    description="Wrappers for the framework Message on macOS",
    max_os_level="10.8",
    packages=["Message"],
    version=VERSION,
    install_requires=["pyobjc-core>=" + VERSION, "pyobjc-framework-Cocoa>=" + VERSION],
    long_description=__doc__,
)
